学年
学期
入学前
入学后

学年
学期

学年
学期

学号：

519027910001

姓名：

林芳

学号：

519027910001

姓名：

林芳

姓名拼音：

曾用名：

性别：

女

证件类型：

居民身份证

证件号码：

300000000000000000

出生日期：

2000-11-01

民族：

人族

政治面貌加入时间：

政治面貌：

地球教女巫

入学日期：

2019-09-07

籍贯：

OPUS_H

户口所在地：

生源地：

OPUS_O

出生地：

港澳台侨外：

国籍/地区：

OPUS_N

年级：

2019

学院名称：

电子信息与电气工程学院

专业名称：

计算机科学与技术(080605)

班级名称：

F1900001

学制：

4

学籍状态：

正常在校

是否在校：

是

报到注册状态：

未报到未注册

报到时间：

2019/9/7 0:00

注册时间：

培养方式：

非定向

所属学院：

电子信息与电气工程学院

招生年度：

考生号：

19300000000000

毕业中学：

地球教教会学校

监护人1姓名：

火车票区间站：

信仰宗教：

来源省：

电子邮箱：

linfei@sjtu.edu.cn

手机号码：

17000000000

家庭地址：

奥伯斯火箭工厂_H

通讯地址：

奥伯斯火箭工厂_M

家庭电话：

10000000

邮政编码：

200000